@@ -1,6 +1,4 @@
 #source $HOME/.poetry/env command imp
-#To publish, cd dutils, then poetry publish
-#poetry add 'module'
 import os
 from xmlrpc.client import Boolean
 import docx2txt
@@ -92,11 +90,11 @@ def save_data(path : str, data : str) -> bool:
     """
     status = False
     file_type = __file_type__(path)
-    if file_type == 1:
+    if file_type == 3:
         status = __txt_file_write__(path, data)
     if file_type == 2:
         status =  __pdf_write__(path, data)
-    if file_type == 3:
+    if file_type == 1:
         status =  __doc_write__(path, data)
     return status
 
@@ -123,13 +121,12 @@ def __pdf_write__(path : str, data : str) -> bool:
 
 def __doc_write__(path : str, data : str) -> bool:
     try:
-        document = Document(path)
-        paragraph = document.paragraphs[len(document.paragraphs) - 1]
-        paragraph.text = data
+        paras = data.split('\n')
+        document = Document()
+        for para in paras:
+            document.add_paragraph(para)
         document.save(path)
         return True
     except Exception as e:
         print("Doc/Docx file could not be modified")
-        raise e
-
-#how to generate github pages
\ No newline at end of file
+        raise e
\ No newline at end of file
